`Problem Set: first_order_intro`

# Young Rabbits

A logic problem by Brandon Bennett

Your problem is to use first-order logic to represent the following example of reasoning, and use the Prover9 theorem prover to prove that the reasoning is valid.

Use the following template file to create your Prover9 encoding of the problem: `young_rabbits.p9`

Marks: There are two marks for each sentence, making a total of 8 marks.

## Problem Statement

A1 | Young rabbits are greedy.
A2 | Greedy animals are fat.
A3 | Rabbits are animals.
Goal | All young rabbits are fat.

### Non-Logical Vocabulary

Predicates: `Young`, `Rabbit`, `Fat`, `Greedy`, `Animal`